@@ -48,7 +48,7 @@ typedef guint32 GrlKeyID;
  * @GRL_MEDIA_TYPE_AUDIO: audio media
  * @GRL_MEDIA_TYPE_VIDEO: video media
  * @GRL_MEDIA_TYPE_IMAGE: image media
- * @GRL_MEDIA_TYPE_CONTAINER: contaddiner media
+ * @GRL_MEDIA_TYPE_CONTAINER: container media
  */
 typedef enum {
   GRL_MEDIA_TYPE_UNKNOWN,
@@ -63,6 +63,8 @@ typedef enum {
 
 #define GRL_METADATA_KEY_INVALID              0
 
+/* BEGIN CORE KEYS */
+
 #define GRL_METADATA_KEY_ALBUM                1
 #define GRL_METADATA_KEY_ARTIST               2
 #define GRL_METADATA_KEY_AUTHOR               3
@@ -114,7 +116,8 @@ typedef enum {
 #define GRL_METADATA_KEY_ORIGINAL_TITLE       49
 #define GRL_METADATA_KEY_SIZE                 50
 #define GRL_METADATA_KEY_TITLE_FROM_FILENAME  51
-#define GRL_METADATA_KEY_MB_ALBUM_ID          52
+#define GRL_METADATA_KEY_MB_ALBUM_ID          52 /* Deprecated: use GRL_METADATA_KEY_MB_RELEASE_ID
+                                                    or GRL_METADATA_KEY_MB_RELEASE_GROUP_ID */
 #define GRL_METADATA_KEY_MB_TRACK_ID          53
 #define GRL_METADATA_KEY_MB_ARTIST_ID         54
 #define GRL_METADATA_KEY_MB_RECORDING_ID      55
@@ -123,6 +126,10 @@ typedef enum {
 #define GRL_METADATA_KEY_ALBUM_DISC_NUMBER    58
 #define GRL_METADATA_KEY_COMPOSER             59
 #define GRL_METADATA_KEY_ALBUM_ARTIST         60
+#define GRL_METADATA_KEY_MB_RELEASE_ID        61
+#define GRL_METADATA_KEY_MB_RELEASE_GROUP_ID  62
+
+/* END CORE KEYS */
 
 G_BEGIN_DECLS
 
